package com.datacloudsec.response;

import com.datacloudsec.exception.UEException;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URLEncoder;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_response.jar:com/datacloudsec/response/FileResponse.class */
public class FileResponse implements IResponse {
    private File file;
    private boolean isDel;
    private boolean success;
    private String downName;

    public FileResponse(File file) {
        this(file, null, false);
    }

    public FileResponse(File file, String downName, boolean isDel) {
        if (file == null || !file.isFile()) {
            throw new UEException("下载的文件不存在！");
        }
        this.file = file;
        this.downName = downName;
        this.isDel = isDel;
    }

    @Override // com.datacloudsec.response.IResponse
    public void shipToResponse(HttpServletRequest request, HttpServletResponse response) {
        String newName;
        String newName2;
        InputStream is = null;
        try {
            try {
                is = new FileInputStream(this.file);
                ServletOutputStream outputStream = response.getOutputStream();
                String oldName = this.file.getName();
                if (StringUtils.isBlank(this.downName)) {
                    newName = oldName;
                } else {
                    newName = this.downName;
                    String newName_houzui = "";
                    String oldName_houzui = "";
                    if (newName.contains(".")) {
                        newName_houzui = newName.substring(newName.lastIndexOf("."));
                    }
                    if (oldName.contains(".")) {
                        oldName_houzui = oldName.substring(oldName.lastIndexOf("."));
                    }
                    if (!oldName_houzui.equals("") && oldName_houzui != null && !oldName_houzui.equals(newName_houzui)) {
                        newName = String.valueOf(newName) + oldName.substring(oldName.lastIndexOf("."));
                    }
                }
                String newName3 = newName.replace(" ", "");
                String userAgent = request.getHeader("user-agent");
                if (StringUtils.isNotBlank(userAgent) && (userAgent.contains("MSIE") || userAgent.contains("Trident"))) {
                    newName2 = URLEncoder.encode(newName3, "UTF-8");
                } else {
                    newName2 = new String(newName3.getBytes("UTF-8"), "ISO-8859-1");
                }
                response.reset();
                response.setContentType("application/octet-stream;charset=utf-8");
                response.setContentLength((int) this.file.length());
                response.setCharacterEncoding("utf-8");
                response.setHeader("Content-Disposition", "attachment; filename=" + newName2);
                response.setHeader("Set-Cookie", "fileDownload=true; path=/");
                byte[] buf = new byte[1024];
                while (true) {
                    int len = is.read(buf);
                    if (len == -1) {
                        break;
                    }
                    outputStream.write(buf, 0, len);
                    outputStream.flush();
                }
                this.success = this.file != null && this.file.isFile() && this.file.length() > 0;
                IOUtils.closeQuietly(is);
                if (this.isDel) {
                    this.file.delete();
                }
            } catch (Exception e) {
                LOG.error("下载文件出错", e);
                IOUtils.closeQuietly(is);
                if (this.isDel) {
                    this.file.delete();
                }
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(is);
            if (this.isDel) {
                this.file.delete();
            }
            throw th;
        }
    }

    @Override // com.datacloudsec.response.IResponse
    public boolean isSuccess() {
        return this.success;
    }
}
